==> kubernetes-model-apiextensions-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceValidationBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomResourceValidationBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationBuilder>{
  public CustomResourceValidationBuilder() {
    this(false);
  }
  public CustomResourceValidationBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomResourceValidation(), validationEnabled);
  }
  public CustomResourceValidationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceValidationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomResourceValidation(), validationEnabled);
  }
  public CustomResourceValidationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation instance) {
    this(fluent, instance, false);
  }
  public CustomResourceValidationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withOpenAPIV3Schema(instance.getOpenAPIV3Schema()); 
    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceValidationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation instance) {
    this(instance,false);
  }
  public CustomResourceValidationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withOpenAPIV3Schema(instance.getOpenAPIV3Schema()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation build() {
    CustomResourceValidation buildable = new CustomResourceValidation(fluent.getOpenAPIV3Schema());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceValidationBuilder that = (CustomResourceValidationBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-apiextensions-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceValidationBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomResourceValidationBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationBuilder>{
  public CustomResourceValidationBuilder() {
    this(false);
  }
  public CustomResourceValidationBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomResourceValidation(), validationEnabled);
  }
  public CustomResourceValidationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceValidationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomResourceValidation(), validationEnabled);
  }
  public CustomResourceValidationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation instance) {
    this(fluent, instance, false);
  }
  public CustomResourceValidationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withOpenAPIV3Schema(instance.getOpenAPIV3Schema()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceValidationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation instance) {
    this(instance,false);
  }
  public CustomResourceValidationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withOpenAPIV3Schema(instance.getOpenAPIV3Schema()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidationFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceValidation build() {
    CustomResourceValidation buildable = new CustomResourceValidation(fluent.getOpenAPIV3Schema());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceValidationBuilder that = (CustomResourceValidationBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
